package com.lantone.qc.kernel.catalogue.crisisvaluereport;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.CrisisValueReportDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @Description: 接到危急值报告后6小时内无病程记录
 * @author: rengb
 * @time: 2020/3/19 19:54
 */
@Component
public class CRI0382 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        List<CrisisValueReportDoc> crisisValueReportDocs = inputInfo.getCrisisValueReportDocs();
        if (ListUtil.isEmpty(crisisValueReportDocs)) {
            return;
        }
        for (CrisisValueReportDoc crisisValueReportDoc : crisisValueReportDocs) {
            String baogaoTimeStr = crisisValueReportDoc.getStructureMap().get("报告时间");
            if (StringUtil.isBlank(baogaoTimeStr)) {
                /* 台州相应数据需从危急值内容中截取 */
                String content = crisisValueReportDoc.getStructureMap().get("内容");
                if (StringUtil.isNotBlank(content)) {
                    baogaoTimeStr = getReportDate(content);
                }
            }
            String jiluTimeStr = crisisValueReportDoc.getStructureMap().get("记录时间");
            if (StringUtil.isNotBlank(baogaoTimeStr) && StringUtil.isNotBlank(jiluTimeStr)) {
                Date baogaoTime = StringUtil.parseDateTime(StringUtil.removeBlank(baogaoTimeStr));
                Date jiluTime = StringUtil.parseDateTime(jiluTimeStr);
                if (baogaoTime != null && jiluTime != null && CatalogueUtil.compareTime(baogaoTime, jiluTime, 6 * 24L)) {
                    status.set("-1");
                    return;
                }
            }
        }
    }

    private String getReportDate(String str) {
        String reportDate = "";
        if (StringUtil.isNotBlank(str) && str.contains("于{") && str.contains("}接到")) {
            reportDate = str.substring(str.indexOf("于{") + 2, str.indexOf("}接到"));
        }
        return reportDate;
    }

}